# TutorialMirror

Contribution by Griatch, 2017

A simple mirror object to experiment with. It will respond to being looked at.

- echoes back the description of the object looking at it
- echoes back whatever is being sent to its .msg - to the
  sender, if given, otherwise to the location of the mirror.

## Installation

Create the mirror with

    create/drop mirror:contrib.tutorials.mirror.TutorialMirror

Then look at it.
